@@ -122,11 +122,11 @@ func (cmd SqlServerCmd) Description() string {
 
 // CreateMarkdown creates a markdown file containing the helptext for the command at the given path
 func (cmd SqlServerCmd) CreateMarkdown(wr io.Writer, commandStr string) error {
-	ap := cmd.CreateArgParser()
+	ap := cmd.ArgParser()
 	return commands.CreateMarkdown(wr, cli.GetCommandDocumentation(commandStr, sqlServerDocs, ap))
 }
 
-func (cmd SqlServerCmd) CreateArgParser() *argparser.ArgParser {
+func (cmd SqlServerCmd) ArgParser() *argparser.ArgParser {
 	serverConfig := DefaultServerConfig()
 
 	ap := argparser.NewArgParser()
@@ -173,7 +173,7 @@ func (cmd SqlServerCmd) Exec(ctx context.Context, commandStr string, args []stri
 }
 
 func startServer(ctx context.Context, versionStr, commandStr string, args []string, dEnv *env.DoltEnv, serverController *ServerController) int {
-	ap := SqlServerCmd{}.CreateArgParser()
+	ap := SqlServerCmd{}.ArgParser()
 	help, _ := cli.HelpAndUsagePrinters(cli.GetCommandDocumentation(commandStr, sqlServerDocs, ap))
 
 	// We need a username and password for many SQL commands, so set defaults if they don't exist
@@ -252,7 +252,9 @@ func getCommandLineServerConfig(dEnv *env.DoltEnv, apr *argparser.ArgParseResult
 			return nil, errors.New("failed to read databases in path specified by --multi-db-dir. error: " + err.Error())
 		}
 
-		serverConfig.withDBNamesAndPaths(dbNamesAndPaths)
+		// We set datadir to multi-db-dir here too
+		// TODO: rename multi-db-dir to data_dir
+		serverConfig.withDBNamesAndPaths(dbNamesAndPaths).withDataDir(multiDBDir)
 	}
 
 	if queryParallelism, ok := apr.GetInt(queryParallelismFlag); ok {
