@@ -735,26 +735,16 @@ func (root *RootValue) CreateEmptyTable(ctx context.Context, tName string, sch s
 		return nil, err
 	}
 
-	emptyRef, err := WriteValAndGetRef(ctx, root.VRW(), empty)
-	if err != nil {
-		return nil, err
-	}
-
-	ed := empty.Edit()
+	indexes := durable.NewIndexSet(ctx, root.VRW())
 	err = sch.Indexes().Iter(func(index schema.Index) (stop bool, err error) {
-		// create an empty indexRowData map for every index
-		ed.Set(types.String(index.Name()), emptyRef)
+		// create an empty map for every index
+		indexes, err = indexes.PutNomsIndex(ctx, index.Name(), empty)
 		return
 	})
 	if err != nil {
 		return nil, err
 	}
 
-	indexes, err := ed.Map(ctx)
-	if err != nil {
-		return nil, err
-	}
-
 	tbl, err := NewTable(ctx, root.VRW(), sch, empty, indexes, nil)
 	if err != nil {
 		return nil, err
@@ -1247,7 +1237,7 @@ func (root *RootValue) DebugString(ctx context.Context, transitive bool) string
 			buf.WriteString("\n")
 
 			buf.WriteString("Data:\n")
-			data, err := table.GetRowData(ctx)
+			data, err := table.GetNomsRowData(ctx)
 			if err != nil {
 				panic(err)
 			}
