@@ -36,6 +36,12 @@ type Schema interface {
 
 	// Checks returns a collection of all check constraints on the table that this schema belongs to.
 	Checks() CheckCollection
+
+	// GetPkOrdinals returns a slice of the primary key ordering indexes relative to the schema column ordering
+	GetPkOrdinals() []int
+
+	// SetPkOrdinals specifies a primary key column ordering
+	SetPkOrdinals([]int) error
 }
 
 // ColFromTag returns a schema.Column from a schema and a tag
@@ -177,5 +183,16 @@ func ArePrimaryKeySetsDiffable(fromSch, toSch Schema) bool {
 		}
 	}
 
+	ords1 := fromSch.GetPkOrdinals()
+	ords2 := toSch.GetPkOrdinals()
+	if ords1 == nil || ords2 == nil || len(ords1) != len(ords2) {
+		return false
+	}
+	for i := 0; i < len(ords1); i++ {
+		if ords1[i] != ords2[i] {
+			return false
+		}
+	}
+
 	return true
 }
