@@ -35,6 +35,7 @@ import (
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dtables"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/globalstate"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/sqlutil"
+	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/writer"
 	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
 	"github.com/dolthub/dolt/go/store/types"
 )
@@ -859,7 +860,7 @@ func (db Database) Flush(ctx *sql.Context) error {
 	if err != nil {
 		return err
 	}
-	editSession := dbState.EditSession
+	editSession := dbState.WriteSession
 
 	newRoot, err := editSession.Flush(ctx)
 	if err != nil {
@@ -873,7 +874,7 @@ func (db Database) Flush(ctx *sql.Context) error {
 
 	// Flush any changes made to temporary tables
 	// TODO: Shouldn't always be updating both roots. Needs to update either both roots or neither of them, atomically
-	tempTableEditSession := dbState.TempTableEditSession
+	tempTableEditSession := dbState.TempTableWriteSession
 	if tempTableEditSession != nil {
 		newTempTableRoot, err := tempTableEditSession.Flush(ctx)
 		if err != nil {
@@ -1030,7 +1031,7 @@ func (db Database) GetStoredProcedures(ctx *sql.Context) ([]sql.StoredProcedureD
 		return nil, nil
 	}
 
-	rowData, err := table.GetRowData(ctx)
+	rowData, err := table.GetNomsRowData(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -1105,38 +1106,21 @@ func (db Database) addFragToSchemasTable(ctx *sql.Context, fragType, name, defin
 		return existingErr
 	}
 
-	// If rows exist, then grab the highest id and add 1 to get the new id
-	indexToUse := int64(1)
 	ts, err := db.TableEditSession(ctx, tbl.IsTemporary())
 	if err != nil {
 		return err
 	}
 
-	te, err := ts.GetTableEditor(ctx, doltdb.SchemasTableName, tbl.sch)
+	root, err := ts.Flush(ctx)
 	if err != nil {
 		return err
 	}
-	dTable, err := te.Table(ctx)
+
+	// If rows exist, then grab the highest id and add 1 to get the new id
+	idx, err := nextSchemasTableIndex(ctx, root)
 	if err != nil {
 		return err
 	}
-	rowData, err := dTable.GetRowData(ctx)
-	if err != nil {
-		return err
-	}
-	if rowData.Len() > 0 {
-		keyTpl, _, err := rowData.Last(ctx)
-		if err != nil {
-			return err
-		}
-		if keyTpl != nil {
-			key, err := keyTpl.(types.Tuple).Get(1)
-			if err != nil {
-				return err
-			}
-			indexToUse = int64(key.(types.Int)) + 1
-		}
-	}
 
 	// Insert the new row into the db
 	inserter := tbl.Inserter(ctx)
@@ -1146,7 +1130,7 @@ func (db Database) addFragToSchemasTable(ctx *sql.Context, fragType, name, defin
 			retErr = err
 		}
 	}()
-	return inserter.Insert(ctx, sql.Row{fragType, name, definition, indexToUse})
+	return inserter.Insert(ctx, sql.Row{fragType, name, definition, idx})
 }
 
 func (db Database) dropFragFromSchemasTable(ctx *sql.Context, fragType, name string, missingErr error) error {
@@ -1176,7 +1160,7 @@ func (db Database) dropFragFromSchemasTable(ctx *sql.Context, fragType, name str
 }
 
 // TableEditSession returns the TableEditSession for this database from the given context.
-func (db Database) TableEditSession(ctx *sql.Context, isTemporary bool) (*editor.TableEditSession, error) {
+func (db Database) TableEditSession(ctx *sql.Context, isTemporary bool) (writer.WriteSession, error) {
 	sess := dsess.DSessFromSess(ctx.Session)
 	dbState, _, err := sess.LookupDbState(ctx, db.Name())
 	if err != nil {
@@ -1184,9 +1168,9 @@ func (db Database) TableEditSession(ctx *sql.Context, isTemporary bool) (*editor
 	}
 
 	if isTemporary {
-		return dbState.TempTableEditSession, nil
+		return dbState.TempTableWriteSession, nil
 	}
-	return dbState.EditSession, nil
+	return dbState.WriteSession, nil
 }
 
 // GetAllTemporaryTables returns all temporary tables
