@@ -160,7 +160,7 @@ func migrateOldSchemasTableToNew(
 		return nil, nil, err
 	}
 
-	rowData, err := table.GetRowData(ctx)
+	rowData, err := table.GetNomsRowData(ctx)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -194,6 +194,34 @@ func migrateOldSchemasTableToNew(
 	return root, rowsToAdd, nil
 }
 
+func nextSchemasTableIndex(ctx *sql.Context, root *doltdb.RootValue) (int64, error) {
+	tbl, _, err := root.GetTable(ctx, doltdb.SchemasTableName)
+	if err != nil {
+		return 0, err
+	}
+
+	rows, err := tbl.GetNomsRowData(ctx)
+	if err != nil {
+		return 0, err
+	}
+
+	idx := int64(1)
+	if rows.Len() > 0 {
+		keyTpl, _, err := rows.Last(ctx)
+		if err != nil {
+			return 0, err
+		}
+		if keyTpl != nil {
+			key, err := keyTpl.(types.Tuple).Get(1)
+			if err != nil {
+				return 0, err
+			}
+			idx = int64(key.(types.Int)) + 1
+		}
+	}
+	return idx, nil
+}
+
 // fragFromSchemasTable returns the row with the given schema fragment if it exists.
 func fragFromSchemasTable(ctx *sql.Context, tbl *WritableDoltTable, fragType string, name string) (sql.Row, bool, error) {
 	indexes, err := tbl.GetIndexes(ctx)
@@ -262,7 +290,7 @@ func getSchemaFragmentsOfType(ctx *sql.Context, tbl *doltdb.Table, fragmentType
 		return nil, errDoltSchemasTableFormat
 	}
 
-	rowData, err := tbl.GetRowData(ctx)
+	rowData, err := tbl.GetNomsRowData(ctx)
 	if err != nil {
 		return nil, err
 	}
