@@ -30,13 +30,14 @@ import (
 	"github.com/dolthub/go-mysql-server/sql"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
+	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb/durable"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema/alterschema"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema/typeinfo"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
-	editor2 "github.com/dolthub/dolt/go/libraries/doltcore/sqle/editor"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/index"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/sqlutil"
+	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/writer"
 	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
 	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor/creation"
 	"github.com/dolthub/dolt/go/store/hash"
@@ -235,7 +236,7 @@ func (t *DoltTable) NumRows(ctx *sql.Context) (uint64, error) {
 		return 0, err
 	}
 
-	return m.Len(), nil
+	return m.Count(), nil
 }
 
 // Format returns the NomsBinFormat for the underlying table
@@ -271,13 +272,11 @@ func (t *DoltTable) Partitions(ctx *sql.Context) (sql.PartitionIter, error) {
 	}
 
 	rowData, err := table.GetRowData(ctx)
-
 	if err != nil {
 		return nil, err
 	}
 
-	numElements := rowData.Len()
-
+	numElements := rowData.Count()
 	if numElements == 0 {
 		return newDoltTablePartitionIter(rowData, doltTablePartition{0, 0, rowData}), nil
 	}
@@ -375,9 +374,9 @@ func partitionRows(ctx *sql.Context, t *doltdb.Table, projCols []string, partiti
 			return emptyRowIterator{}, nil
 		}
 
-		return newRowIterator(ctx, t, projCols, &typedPartition)
+		return newRowIterator(ctx, t, projCols, typedPartition)
 	case index.SinglePartition:
-		return newRowIterator(ctx, t, projCols, &doltTablePartition{rowData: typedPartition.RowData, end: NoUpperBound})
+		return newRowIterator(ctx, t, projCols, doltTablePartition{rowData: typedPartition.RowData, end: NoUpperBound})
 	}
 
 	return nil, errors.New("unsupported partition type")
@@ -387,7 +386,7 @@ func partitionRows(ctx *sql.Context, t *doltdb.Table, projCols []string, partiti
 type WritableDoltTable struct {
 	*DoltTable
 	db Database
-	ed editor2.TableEditor
+	ed writer.TableWriter
 }
 
 var _ doltTableInterface = (*WritableDoltTable)(nil)
@@ -434,24 +433,41 @@ func (t *WritableDoltTable) Inserter(ctx *sql.Context) sql.RowInserter {
 	return te
 }
 
-func (t *WritableDoltTable) getTableEditor(ctx *sql.Context) (ed editor2.TableEditor, err error) {
-	sess := dsess.DSessFromSess(ctx.Session)
+func (t *WritableDoltTable) getTableEditor(ctx *sql.Context) (ed writer.TableWriter, err error) {
+	ds := dsess.DSessFromSess(ctx.Session)
+
+	var batched = ds.BatchMode() == dsess.Batched
 
 	// In batched mode, reuse the same table editor. Otherwise, hand out a new one
-	if sess.BatchMode() == dsess.Batched {
+	if batched {
 		if t.ed != nil {
 			return t.ed, nil
 		}
 	}
 
-	vrw := t.db.ddb.ValueReadWriter()
+	ws, err := ds.WorkingSet(ctx, t.db.name)
+	if err != nil {
+		return nil, err
+	}
+	ait := t.db.gs.GetAutoIncrementTracker(ws.Ref())
 
-	ed, err = editor2.NewSqlTableEditor(ctx, sess, t, t.db, t.db.gs, t.sch, vrw)
+	state, _, err := ds.LookupDbState(ctx, t.db.name)
 	if err != nil {
 		return nil, err
 	}
 
-	if sess.BatchMode() == dsess.Batched {
+	if t.temporary {
+		setter := ds.SetTempTableRoot
+		ed, err = state.TempTableWriteSession.GetTableWriter(ctx, t.tableName, t.db.Name(), ait, setter, batched)
+	} else {
+		setter := ds.SetRoot
+		ed, err = state.WriteSession.GetTableWriter(ctx, t.tableName, t.db.Name(), ait, setter, batched)
+	}
+	if err != nil {
+		return nil, err
+	}
+
+	if batched {
 		t.ed = ed
 	}
 
@@ -487,13 +503,13 @@ func (t *WritableDoltTable) Truncate(ctx *sql.Context) (int, error) {
 	if err != nil {
 		return 0, err
 	}
-	numOfRows := int(rowData.Len())
+	numOfRows := int(rowData.Count())
 	empty, err := types.NewMap(ctx, table.ValueReadWriter())
 	if err != nil {
 		return 0, err
 	}
 	// truncate table resets auto-increment value
-	newTable, err := doltdb.NewTable(ctx, table.ValueReadWriter(), t.sch, empty, empty, nil)
+	newTable, err := doltdb.NewTable(ctx, table.ValueReadWriter(), t.sch, empty, nil, nil)
 	if err != nil {
 		return 0, err
 	}
@@ -656,11 +672,11 @@ var _ sql.PartitionIter = (*doltTablePartitionIter)(nil)
 type doltTablePartitionIter struct {
 	i          int
 	mu         *sync.Mutex
-	rowData    types.Map
+	rowData    durable.Index
 	partitions []doltTablePartition
 }
 
-func newDoltTablePartitionIter(rowData types.Map, partitions ...doltTablePartition) *doltTablePartitionIter {
+func newDoltTablePartitionIter(rowData durable.Index, partitions ...doltTablePartition) *doltTablePartitionIter {
 	return &doltTablePartitionIter{0, &sync.Mutex{}, rowData, partitions}
 }
 
@@ -684,7 +700,7 @@ func (itr *doltTablePartitionIter) Next(*sql.Context) (sql.Partition, error) {
 	return partition, nil
 }
 
-var _ sql.Partition = (*doltTablePartition)(nil)
+var _ sql.Partition = doltTablePartition{}
 
 const NoUpperBound = 0xffffffffffffffff
 
@@ -693,7 +709,7 @@ type doltTablePartition struct {
 	start uint64
 	// all elements in the partition will be less than end (exclusive)
 	end     uint64
-	rowData types.Map
+	rowData durable.Index
 }
 
 // Key returns the key for this partition, which must uniquely identity the partition.
@@ -704,7 +720,8 @@ func (p doltTablePartition) Key() []byte {
 // IteratorForPartition returns a types.MapIterator implementation which will iterate through the values
 // for index = start; index < end.  This iterator is not thread safe and should only be used from a single go routine
 // unless paired with a mutex
-func (p doltTablePartition) IteratorForPartition(ctx context.Context, m types.Map) (types.MapTupleIterator, error) {
+func (p doltTablePartition) IteratorForPartition(ctx context.Context, idx durable.Index) (types.MapTupleIterator, error) {
+	m := durable.NomsMapFromIndex(idx)
 	return m.RangeIterator(ctx, p.start, p.end)
 }
 
