@@ -42,7 +42,7 @@ func TestKeylessTableEditorConcurrency(t *testing.T) {
 	require.NoError(t, err)
 	emptyMap, err := types.NewMap(context.Background(), db)
 	require.NoError(t, err)
-	table, err := doltdb.NewTable(context.Background(), db, tableSch, emptyMap, emptyMap, nil)
+	table, err := doltdb.NewTable(context.Background(), db, tableSch, emptyMap, nil, nil)
 	require.NoError(t, err)
 
 	opts := TestEditorOptions(db)
@@ -104,7 +104,7 @@ func TestKeylessTableEditorConcurrency(t *testing.T) {
 
 		newTable, err := tableEditor.Table(context.Background())
 		require.NoError(t, err)
-		newTableData, err := newTable.GetRowData(context.Background())
+		newTableData, err := newTable.GetNomsRowData(context.Background())
 		require.NoError(t, err)
 
 		require.Equal(t, newTableData.Len(), uint64(100))
@@ -150,7 +150,7 @@ func TestKeylessTableEditorConcurrencyPostInsert(t *testing.T) {
 	require.NoError(t, err)
 	emptyMap, err := types.NewMap(context.Background(), db)
 	require.NoError(t, err)
-	table, err := doltdb.NewTable(context.Background(), db, tableSch, emptyMap, emptyMap, nil)
+	table, err := doltdb.NewTable(context.Background(), db, tableSch, emptyMap, nil, nil)
 	require.NoError(t, err)
 
 	opts := TestEditorOptions(db)
@@ -210,7 +210,7 @@ func TestKeylessTableEditorConcurrencyPostInsert(t *testing.T) {
 
 		newTable, err := tableEditor.Table(context.Background())
 		require.NoError(t, err)
-		newTableData, err := newTable.GetRowData(context.Background())
+		newTableData, err := newTable.GetNomsRowData(context.Background())
 		require.NoError(t, err)
 
 		require.Equal(t, newTableData.Len(), uint64(100))
@@ -257,7 +257,7 @@ func TestKeylessTableEditorWriteAfterFlush(t *testing.T) {
 	require.NoError(t, err)
 	emptyMap, err := types.NewMap(context.Background(), db)
 	require.NoError(t, err)
-	table, err := doltdb.NewTable(context.Background(), db, tableSch, emptyMap, emptyMap, nil)
+	table, err := doltdb.NewTable(context.Background(), db, tableSch, emptyMap, nil, nil)
 	require.NoError(t, err)
 
 	opts := TestEditorOptions(db)
@@ -289,7 +289,7 @@ func TestKeylessTableEditorWriteAfterFlush(t *testing.T) {
 
 	newTable, err := tableEditor.Table(context.Background())
 	require.NoError(t, err)
-	newTableData, err := newTable.GetRowData(context.Background())
+	newTableData, err := newTable.GetNomsRowData(context.Background())
 	require.NoError(t, err)
 
 	seen := make([]bool, 10)
@@ -321,7 +321,7 @@ func TestKeylessTableEditorWriteAfterFlush(t *testing.T) {
 
 	sameTable, err := tableEditor.Table(context.Background())
 	require.NoError(t, err)
-	sameTableData, err := sameTable.GetRowData(context.Background())
+	sameTableData, err := sameTable.GetNomsRowData(context.Background())
 	require.NoError(t, err)
 	assert.True(t, sameTableData.Equals(newTableData))
 }
@@ -338,7 +338,7 @@ func TestKeylessTableEditorDuplicateKeyHandling(t *testing.T) {
 	require.NoError(t, err)
 	emptyMap, err := types.NewMap(context.Background(), db)
 	require.NoError(t, err)
-	table, err := doltdb.NewTable(context.Background(), db, tableSch, emptyMap, emptyMap, nil)
+	table, err := doltdb.NewTable(context.Background(), db, tableSch, emptyMap, nil, nil)
 	require.NoError(t, err)
 
 	opts := TestEditorOptions(db)
@@ -384,7 +384,7 @@ func TestKeylessTableEditorDuplicateKeyHandling(t *testing.T) {
 
 	newTable, err := tableEditor.Table(context.Background())
 	require.NoError(t, err)
-	newTableData, err := newTable.GetRowData(context.Background())
+	newTableData, err := newTable.GetNomsRowData(context.Background())
 	require.NoError(t, err)
 
 	seen := make([]bool, 10)
@@ -437,7 +437,7 @@ func TestKeylessTableEditorMultipleIndexErrorHandling(t *testing.T) {
 	require.NoError(t, err)
 	emptyMap, err := types.NewMap(ctx, db)
 	require.NoError(t, err)
-	table, err := doltdb.NewTable(ctx, db, tableSch, emptyMap, emptyMap, nil)
+	table, err := doltdb.NewTable(ctx, db, tableSch, emptyMap, nil, nil)
 	require.NoError(t, err)
 	table, err = RebuildAllIndexes(ctx, table, opts)
 	require.NoError(t, err)
@@ -478,7 +478,7 @@ func TestKeylessTableEditorMultipleIndexErrorHandling(t *testing.T) {
 
 	table, err = tableEditor.Table(ctx)
 	require.NoError(t, err)
-	tableData, err := table.GetRowData(ctx)
+	tableData, err := table.GetNomsRowData(ctx)
 	require.NoError(t, err)
 
 	seen := make([]bool, 13)
@@ -507,7 +507,7 @@ func TestKeylessTableEditorMultipleIndexErrorHandling(t *testing.T) {
 		}
 	}
 
-	idxv1Data, err := table.GetIndexRowData(ctx, "idx_v1")
+	idxv1Data, err := table.GetNomsIndexRowData(ctx, "idx_v1")
 	require.NoError(t, err)
 
 	seen = make([]bool, 13)
@@ -539,7 +539,7 @@ func TestKeylessTableEditorMultipleIndexErrorHandling(t *testing.T) {
 		}
 	}
 
-	idxv2Data, err := table.GetIndexRowData(ctx, "idx_v2")
+	idxv2Data, err := table.GetNomsIndexRowData(ctx, "idx_v2")
 	require.NoError(t, err)
 
 	seen = make([]bool, 13)
@@ -590,7 +590,7 @@ func TestKeylessTableEditorIndexCardinality(t *testing.T) {
 	require.NoError(t, err)
 	emptyMap, err := types.NewMap(ctx, db)
 	require.NoError(t, err)
-	table, err := doltdb.NewTable(ctx, db, tableSch, emptyMap, emptyMap, nil)
+	table, err := doltdb.NewTable(ctx, db, tableSch, emptyMap, nil, nil)
 	require.NoError(t, err)
 	table, err = RebuildAllIndexes(ctx, table, opts)
 	require.NoError(t, err)
@@ -614,7 +614,7 @@ func TestKeylessTableEditorIndexCardinality(t *testing.T) {
 	table, err = tableEditor.Table(ctx)
 	require.NoError(t, err)
 
-	idxv1Data, err := table.GetIndexRowData(ctx, "idx_v1")
+	idxv1Data, err := table.GetNomsIndexRowData(ctx, "idx_v1")
 	require.NoError(t, err)
 
 	seen := make([]bool, 3)
